#include <hidef.h> /* for EnableInterrupts macro */
#include "derivative.h" /* include peripheral declarations */

#include "LIB_ICS.h"			// ICS functions
#include "LIB_LCD.h"			// LCD driver functions
#include "sci.h"				// SCI functions

#define STATE_L   1
#define STATE_E   2
#define STATE_4   3
#define STATE_D   4
#define STATE_e   5
#define STATE_M   6

#define SW1 PTAD_PTAD4
#define SW2	PTDD_PTDD5

#define LED1 PTDD_PTDD6
#define LED2 PTAD_PTAD3
#define LED3 PTAD_PTAD1
#define LED4 PTAD_PTAD0

void ICS_FEE_32K768_8M388608(void);	// ICS setup function		 
void init_KBI(void);						// enable KBI
void LE4_FT(void);						// Peripheral Test routine


//#define FEI
#define FEE_32K768 

byte state;                         

void main(void) {

  EnableInterrupts; /* enable interrupts */
  
  SOPT = 0x23; /* disable the COP, enable the stop mode */
  
  PMCSC = 0x0; /* disable LVD */
  
	PTAPE_PTAPE4 = 1;					// PTA4 pull up enabled
	PTDPE_PTDPE5 = 1;					// PTD5 pull up enabled

#ifdef FEE_32K768   /* ICS FEE mode, external crystal 32K768, bus clk about 8M */
  ICS_FEE_32K768_8M388608();
  ICSC2_ERCLKEN = 1;
  ICSC2_EREFSTEN = 1;
#endif

#ifdef FEI  /* ICS FEI mode, internal reference clk, bus clk 8M */
  ICS_FEI_8M();
#endif
  
	if(!SW1 | !SW2) LE4_FT();			// execute peripheral test if either SW pressed
												// else run LCD DEMO

  PTADD = 0xFF;   /* configue all pad output low */
  PTBDD = 0xFC;
  PTCDD = 0x03;
  PTDDD = 0xFF;  

  LCD_CONFIG;     /* Put LCD controller in the conguration mode */

#ifdef FEE_32K768 
  LCD_CLK_EX;     /* choose the external clock source */
#endif

#ifdef FEI 
  LCD_CLK_FF;     /* choose the fixed clock source */
#endif
  
  LCDSUPPLY_LADJ    = 0x0;   /* set these 2 bits according to the external LCD glass capacity */
  
  LCDSUPPLY_VSUPPLY = 0x1;
  
  LCDC1 = 0x0;               /* Enable the LCD display in the wait and stop mode */
  
  LCD_DUTY_1_8;              /* 1/8 duty cycle */
  
  LCDC0_LCLK = 5;            /* choose the frame frequency */
  
  LCDBCTL = 0;               /* disable the blink mode */
  
  LCDPEN0 = 0xFF;            /* Enable the LCD pin */
  LCDPEN1 = 0xFF;
  LCDPEN2 = 0x3F;
  
  LCDBPEN0 = 0x0F;           /* Configure the LCD backplane pin */
  LCDBPEN1 = 0x00;
  LCDBPEN2 = 0x3C;
  
  LCD_WF_init();             /* Configure WF register to the default value */

  LCD_DISPLAY;               /* Switch the LCD controller to the display mode */
  
  state = STATE_L;           /* put the state machine in the initial state, STATE_L */
  
  SRTISC = 0x57;             /* start the RTI, F = 1Hz */

  for (;;) {
  
    LCD_CONFIG;              /* Switch the LCD controller to the configue mode */
  
    if (state == STATE_L) {
    
      LCD_pos_buf(1,' ');        /* Display "     L" */
      LCD_pos_buf(2,' ');
      LCD_pos_buf(3,' ');
      LCD_pos_buf(4,' ');
      LCD_pos_buf(5,' ');
      LCD_pos_buf(6,'L');
      
      SET_LOGO;
      
      LCD_Buf_WF();
    
      state = STATE_E;       /* put the state machine in the state, STATE_E */
  
    } else if (state == STATE_E) {
    
      LCD_pos_buf(1,' ');        /* Display "    LE" */
      LCD_pos_buf(2,' ');
      LCD_pos_buf(3,' ');
      LCD_pos_buf(4,' ');
      LCD_pos_buf(5,'L');
      LCD_pos_buf(6,'E');
      
      SET_LOGO;
      
      LCD_Buf_WF();
    
      state = STATE_4;       /* put the state machine in the state, STATE_4 */
    
    } else if (state == STATE_4) {
    
      LCD_pos_buf(1,' ');        /* Display "   LE4" */
      LCD_pos_buf(2,' ');
      LCD_pos_buf(3,' ');
      LCD_pos_buf(4,'L');
      LCD_pos_buf(5,'E');
      LCD_pos_buf(6,'4');
      
      SET_LOGO;
      
      LCD_Buf_WF();
    
      state = STATE_D;       /* put the state machine in the state, STATE_D */
    
    } else if (state == STATE_D) {
    
      LCD_pos_buf(1,' ');        /* Display "  LE4D" */
      LCD_pos_buf(2,' ');
      LCD_pos_buf(3,'L');
      LCD_pos_buf(4,'E');
      LCD_pos_buf(5,'4');
      LCD_pos_buf(6,'D');
      
      SET_LOGO;
      
      LCD_Buf_WF();
    
      state = STATE_e;       /* put the state machine in the state, STATE_e */
    
    } else if (state == STATE_e) {
    
      LCD_pos_buf(1,' ');        /* Display " LE4DE" */
      LCD_pos_buf(2,'L');
      LCD_pos_buf(3,'E');
      LCD_pos_buf(4,'4');
      LCD_pos_buf(5,'D');
      LCD_pos_buf(6,'E');
      
      SET_LOGO;
      
      LCD_Buf_WF();
    
      state = STATE_M;       /* put the state machine in the state, STATE_M */
    
    } else if(state == STATE_M) {
    
      LCD_pos_buf(1,'L');        /* Display "LE4DEM" */
      LCD_pos_buf(2,'E');
      LCD_pos_buf(3,'4');
      LCD_pos_buf(4,'D');
      LCD_pos_buf(5,'E');
      LCD_pos_buf(6,'M');
      
      SET_LOGO;
      
      LCD_Buf_WF();
    
      state = STATE_L;       /* put the state machine in the state, STATE_L */
    
    } 
    LCD_DISPLAY;
    
#ifdef FEE_32K768 
    asm{
    stop
    }
#endif
  
    while (SIP1 != 0x01);
    while (!SRTISC_RTIF);
    SRTISC_RTIACK = 0x1;  
  } // end of loop
} //end of main


// Peripheral Test routine for DEMO9RS08LE4 board
	
void LE4_FT(void) {
	char n;
	
//	DisableInterrupts;
//	SOPT = 0x23;						// disable the COP, enable the stop mode 
	
//	ICS_FEE_32K768_8M388608();		// configure clock source 

//	PTAPE_PTAPE4 = 1;					// PTA4 pull up enabled
//	PTDPE_PTDPE5 = 1;					// PTD5 pull up enabled
	
	PTAD = 0x0B;						// init PTA
	PTADD = 0x0B;						// PTA[3,1,0] output
	
	PTDD_PTDD6 = 1;					//init PTD[6]
	PTDDD_PTDDD6 = 1;					// PTD[6] output

	LCDC0_LCDEN = 0;					// disable LCD module
	LCDC0_SOURCE = 1;
	LCDSUPPLY_CPSEL = 0;
	
	// setup TPM2CH0 for use w/ buzzer 
	TPM2C0SC_MS0x = 1;				// select ouput compare
	TPM2C0SC_ELS0x = 1;				// toggle on compare
	TPM2MODH = 0x00;
	TPM2MODL = 0x82;					// load count	
	TPM2SC_PS = 0x03;					// input clock div by 8
	TPM2SC_CLKSx = 1;					// start timer 2 @ bus clk input
	
	if(!SW2){
		ensci();							// enable SCI output 19200,8,N,1
		while(SW1){						// exit on SW1 press
			if(SCIS1_RDRF){			// if data available at COM port 
				putchar(ReadSerialPort());	// get data and echo to COM port
			}
		}
	}
		
	if(!SW1) {
		n = 0;
		LED1 = LED3 =  1;				// LED1, LED3 OFF
		LED2 = LED4 =  0;				// LED2, LED4 ON
		SCIC2 = 0;						// disable SCI 															 
											// setup timer 2 to output 2.5 Hz
		TPM2SC_CLKSx = 0;				// disable timer
		TPM2C0SC_ELS0x = 0;			// timer pin used for GPIO
		TPM2SC_PS = 0x07;				// input clock div by 64
		TPM2MODH = 0x19;
		TPM2MODL = 0x99;				// load count	
		TPM2SC_CLKSx = 1;				// start timer 2 @ bus clk input
		while((SW2)){					// exit on SW2 press
			if(TPM2SC_TOF){
				TPM2SC_TOF = 0;		// clr TOF
				LED1 ^= 1;				// toggle LED1
				LED2 ^= 1;				// toggle LED2
				LED3 ^= 1;				// toggle LED3
				LED4 ^= 1;				// toggle LED4
			}
		}
	}
}

